<?php
/**
 * An interface for front-end database classes. The classes should prepare the
 * objects for saving in the database. So for server-bases database classes SQL
 * queries shall be generated and send to the backend classes. In case of local
 * file databases the object shall be serialized and (maybe) transparently
 * compressed before they got saved to a local file.
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface DatabaseFrontendInterface extends FrameworkDatabaseInterface {
	/**
	 * Makes sure that the database connection is up and alive
	 *
	 * @return	void
	 */
	function connectToDatabase ();

	/**
	 * Starts a SELECT query on the database by given return type, table name
	 * and search criteria
	 *
	 * @param	$resultType		Result type ('array', 'object' and 'indexed' are valid)
	 * @param	$tableName		Name of the database table
	 * @param	$criteria		Search criteria class
	 * @return	$resultData		Result data of the query
	 * @throws	UnsupportedCriteriaException	If the criteria is unsupported
	 * @throws	SqlException					If an SQL error occurs
	 */
	function querySelect ($resultType, $tableName, LocalSearchCriteria $criteriaInstance);

	/**
	 * 'Inserts' a data set instance into a local file database folder
	 *
	 * @param	$dataSetInstance	A storeable data set
	 * @return	void
	 * @throws	SqlException	If an SQL error occurs
	 */
	function queryInsertDataSet (StoreableCriteria $dataSetInstance);

	/**
	 * 'Updates' a data set instance with a database layer
	 *
	 * @param	$dataSetInstance	A storeable data set
	 * @return	void
	 * @throws	SqlException	If an SQL error occurs
	 */
	function queryUpdateDataSet (StoreableCriteria $dataSetInstance);
}

// [EOF]
?>
